# eric7.SystemUtilities.PythonUtilities

Module implementing Python related utility functions.

### Global Attributes

None

### Classes

None

### Functions

determinePythonVersion | Function to determine the python version of a given file.
getPythonExecutable | Function to determine the path of the (non-windowed) Python executable.
getPythonLibPath | Function to determine the path to Python's library.
getPythonLibraryDirectory | Function to determine the path to Python's library directory.
getPythonScriptsDirectory | Function to determine the path to Python's scripts directory.
getPythonVersion | Function to get the Python version (major, minor) as an integer value.

## determinePythonVersion

determinePythonVersion(filename, source, editor=None)

Function to determine the python version of a given file.

filename
  name of the file with extension (str)
source
  of the file (str)
editor
  reference to the editor, if the file is opened already (Editor object)

Return:
  Python version if file is Python3 (int)

Up

## getPythonExecutable

getPythonExecutable()

Function to determine the path of the (non-windowed) Python executable.

Return:
  path of the Python executable

Return Type:
  str

Up

## getPythonLibPath

getPythonLibPath()

Function to determine the path to Python's library.

Return:
  path to the Python library (string)

Up

## getPythonLibraryDirectory

getPythonLibraryDirectory()

Function to determine the path to Python's library directory.

Return:
  path to the Python library directory

Return Type:
  str

Up

## getPythonScriptsDirectory

getPythonScriptsDirectory()

Function to determine the path to Python's scripts directory.

Return:
  path to the Python scripts directory

Return Type:
  str

Up

## getPythonVersion

getPythonVersion()

Function to get the Python version (major, minor) as an integer value.

Return:
  An integer representing major and minor version number (integer)

Up